const app = getApp();
Page({
  data: {
    latitude: "24.47951",
    longitude: "118.08948",
    markers: [], //点
    polyline: [], //线
    polygons: [], //区域
    list: [],
    fence: [],
    area_id: '', //区域id
    max_number: '', //停车上限
    name: '', //停车区域名字
    status: '', //停车区状态
    type: '', //停车区类型
  },

  onLoad(options) {
    this.setData({
      area_id: options.area_id,
      max_number: options.max_number,
      name: options.name,
      status: options.status,
      type: options.type,
    })
    let that = this;
    that.getArea();
    wx.getLocation({
      type: 'gcj02',
      success: function(res) {
        let latitude = res.latitude;
        let longitude = res.longitude;
        console.log(latitude, longitude)
        that.setData({
          latitude: latitude,
          longitude: longitude
        })
      },
    })
  },
  // 获取停车区列表
  getArea() {
    var that = this;
    app.request('getAreas', '', 'GET').then(res => {
      console.log(res.data)
      let data = [];
      data = data.concat(res.data.parking_area)
      data = data.concat(res.data.no_parking_area)
      var arr = [];
      if (data.length == 0) {
        wx.showToast({
          title: '无还车点',
          icon: 'none'
        })
      } else {
        for (var i = 0; i < data.length; i++) {
          arr = arr.concat(data[i])
        }
        for (var i = 0; i < arr.length; i++) {
          let color = '';
          let bgColor = '';
          if(arr[i].type == 1){
            color='#FF0000';
            bgColor = "#FF000022"
          }
          if(arr[i].type == 2){
            color = '#18D3B8';
            bgColor = "#18D3B822"
          }
          arr[i].points = arr[i].parking_fence_wx;
          arr[i].strokeWidth = 4;
          arr[i].strokeColor = color;
          arr[i].fillColor = bgColor;
          arr[i].zIndex = 1;
        }
        that.setData({
          polygons: that.data.polygons.concat(arr),
        })
      }
    })
  },
  //重绘
  again() {
    this.getArea();
    this.setData({
      polygons: [],
      markers: [],
      polyline: [],
      list: []
    })
  },
  // 点击地图事件
  mapclick(e) {
    let that = this;
    let arr = that.data.list;
    arr.push(e.detail)
    let iconPath = '';
    let color = '';
    let bgColor = '';
    if (that.data.type == 1) { //禁停区
      iconPath = "http://resource.weilaibike.com/lixian.png";
      color = "#FF0000";
      bgColor = "#FF000022"
    } else if (that.data.type == 2) { //停车区
      iconPath = "http://resource.weilaibike.com/common/riding_app.png";
      color = "#18D5B9";
      bgColor = "#18D5B922"
    }
    if (arr.length == 1) {
      let dot = {};
      dot.id = 0;
      dot.latitude = arr[0].latitude;
      dot.longitude = arr[0].longitude;
      dot.iconPath = iconPath
      dot.width = 28;
      dot.height = 28;
      console.log(dot)
      let dotArr = [];
      dotArr.push(dot)
      that.setData({
        markers: dotArr
      })
    }

    if (arr.length >= 2) {
      let line = {};
      line.points = arr
      line.width = 4;
      line.color = color;
      line.borderWidth = 3;
      line.borderColor = color;
      let lineArr = [];
      lineArr.push(line)
      that.setData({
        polyline: lineArr,
        markers: ''
      })
    }
    if (arr.length >= 3) {
      let area = {};
      that.setData({
        fence: arr
      })
      console.log(arr)
      area.points = arr;
      area.fillColor = bgColor;
      area.strokeColor = color;
      area.strokeWidth = 4;
      area.zIndex = 1;
      let areaArr = []
      areaArr.push(area)
      that.setData({
        polygons: that.data.polygons.concat(areaArr),
        polyline: ''
      })
    }
  },
  //完成
  finish() {
    let that = this;
    let state = JSON.parse(that.data.status);
    let parking_fence = []
    that.data.fence.map(i => {
      parking_fence.push({
        lat: i.latitude,
        lng: i.longitude
      })
    })
    if (state) {
      state = 1
    } else {
      state = 0
    }
    console.log(state)
    let data = {
      parking_fence: JSON.stringify(parking_fence),
      area_id: that.data.area_id,
      max_number: that.data.max_number,
      name: that.data.name,
      status: state,
      type: that.data.type,
    }
    app.request('parking', data, 'POST').then(res => {
      if (res.statusCode == 201) {
        console.log(that.data.type, 555)
        console.log(res);
        wx.showToast({
          title: '添加成功',
          icon: 'none',
          duration: 3000,
          success: function() {
            setTimeout(function() {
              wx.reLaunch({
                url: '/pages/parkMange/parkManage?type=' + that.data.type,
              })
            }, 3000)
          }
        })
      }
    })
  },
})